-- Filename: main.lua
-- Author: Peter Dijkstra

-- Requires
require "lib/middleclass" --MiddleClass for OOP
HardonCollider = require "lib/HardonCollider" --Collision detection
require "lib/mylib"
inspect = require "lib/inspect"

require "scripts/Map"
require "scripts/HUD"
require "scripts/Player"
require "scripts/Chest"

require "scripts/Weapon"
require "scripts/weapons/Sword"
require "scripts/weapons/Bow"
require "scripts/weapons/Arrow"

require "scripts/Enemies"
require "scripts/enemies/Zombie"


-- Initialization
function love.load()
	
	-- Debug controls
	activateDebug = true -- true = debug on, false = debug off.
	showCBox    = true -- true = visible CBoxes, false = invisble. Controlled with key 1.
	showDebugText = true -- true = visible overlay text, false = invisble. Controlled with key 2.

	-- Activate HardonCollider
	Collider = HardonCollider(100, on_collide, not_collide)
	
	font = love.graphics.newFont("font/pf_westa_seven.ttf", 8)
	love.graphics.setFont(font)

	-- White background is better
	love.graphics.setBackgroundColor(255,255,255)
	
	gWidth  = love.graphics.getWidth()
	gHeight = love.graphics.getHeight()

	testMap = Map:new()
	testMap:initialize()

	display = HUD:new()
	display:initialize()

	player = Player:new()
	player:initialize()

	enemyHandler = Enemies:new()
	enemyHandler:initialize()

	newChest = Chest:new()
	newChest:initialize()

	love.graphics.setLine(1, "rough")
	love.graphics.setPoint(1, "rough")

end

-- Rendering
function love.draw()

	testMap:draw()
	display:draw()
	player:draw()
	enemyHandler:draw()
	newChest:draw()
	
	-- Onscreen debug text
	if showDebugText == true then
		love.graphics.setColor(0,0,0)
		love.graphics.rectangle("fill", 0, gHeight - 16, gWidth, gHeight)
		love.graphics.setColor(255,255,255)
		love.graphics.print("# = " .. #player.weapon.equip .. " [1] = " .. tostring(player.weapon.equip[1]), 10, gHeight - 16)
		-- Display FPS
		love.graphics.print(fps, gWidth - 25, gHeight - 16)
	end

end

-- Logic
function love.update(dt)

	player:movement(dt)
	player:update(dt)

	enemyHandler:update(dt)

	fps = love.timer.getFPS()
	
	Collider:update(dt)
end

-- Key presses
function love.keypressed(key)
	
	if key == "escape" then
		love.event.quit()
	end
	
	if activateDebug == true then
		-- Show HardonCollider collision boxes
		if key == "1" then
			if showCBox == false then
				showCBox = true
			else
				showCBox = false
			end
		end
		
		-- Show overlay debug text
		if key == "2" then
			if showDebugText == false then
				showDebugText = true
			else
				showDebugText = false
			end
		end

		if key == "3" then
			newChest:refresh()
			player.x, player.y = 32, 32
		end

		-- Enter interactive mode
		if key == "0" then
			debug.debug()
		end
	end

end

function on_collide(dt, shape_a, shape_b, mtv_x, mtv_y)

	local _player = player.cBox

	if shape_b == _player and shape_a == testMap.cBox1 
	or shape_a == testMap.cBox2 
	or shape_a == testMap.cBox3 
	or shape_a == testMap.cBox4 then
		player:halt(mtv_x,mtv_y)
	end

	if shape_b == zoombie.cBox and shape_a == testMap.cBox1 
	or shape_a == testMap.cBox2 
	or shape_a == testMap.cBox3 
	or shape_a == testMap.cBox4 then
		zoombie:halt(mtv_x,mtv_y)
	end

	if shape_b == newChest.cBox and shape_a == _player then
		player.weapon:swap()
		newChest:refresh()
		player.score = player.score + 1
	end

	if shape_a == player.weapon.equip[#player.weapon.equip].cBox and shape_b == newChest.cBox then
		trace("poke poke poke")
	end

	if shape_a == _player and shape_b == zoombie.cBox then
		player:halt(-mtv_x,-mtv_y)
		player:force(-mtv_x, -mtv_y, dt)
	end

	if shape_a == player.weapon.equip[#player.weapon.equip].cBox and shape_b == zoombie.cBox then
		trace("Zombie hit by " .. tostring(player.weapon.equip[#player.weapon.equip]))
	end

end

function not_collide(dt, shape_a, shape_b)

end