Player = class('Player', Object)

function Player:initialize()
	Object.initialize(self)
  
	self.x    = 64
	self.y    = 64
	self.cBox = Collider:addRectangle(self.x,self.y,16,16)
	self.direction = "down"
	self.score = 0

	self.weapon = Weapon:new()
	self.weapon:initialize(self.x,self.y)

	Collider:addToGroup("player", self.cBox)

	self.img  = { particle = love.graphics.newImage("img/dust.png") }

	self.velocity = {
		x        = 0,
		y        = 0,
		Increase = 5,
		Max      = 100,
	}

	self.bDash = {
		TimeMargin = 0.3,
		Timer = {
			Up    = 0,
			Down  = 0,
			Left  = 0,
			Right = 0,
			},
		Pushed = {
			Up    = false,
			Down  = false,
			Left  = false,
			Right = false,
			},
		PartSys = love.graphics.newParticleSystem(self.img.particle, 256),
	}

	self.forceTimer = 0
	self.allowDecrease = true
	self.forced = false
	self.mX = 0
	self.mY = 0

	local p = self.bDash.PartSys
	p:setEmissionRate          (10)
	p:setLifetime              (0.3)
	p:setParticleLife          (0.5)
	p:setDirection             (0)
	p:setSpread                (2.5)
	p:setSpeed                 (30, 50)
	p:setRadialAcceleration    (10)
	p:setTangentialAcceleration(0)
	p:setSizes                 (1)
	p:setSizeVariation         (0.5)
	p:setRotation              (0)
	p:setSpin                  (5)
	p:setSpinVariation         (1)
	p:stop()

end

function Player:draw()

	love.graphics.draw(self.bDash.PartSys,8,8)

	love.graphics.setColor(0,50,200)
	love.graphics.rectangle("fill",self.x,self.y,16,16)

	if showCBox == true then
		love.graphics.setColor(0,0,0)
		self.cBox:draw("line")
	end

	self.weapon:draw();
end

function Player:update(dt)

	self.bDash.PartSys:setPosition(self.x,self.y)
	self.bDash.PartSys:update(dt)

	self.weapon.x = self.x
	self.weapon.y = self.y
	self.weapon:update(dt)
	self.weapon:fire(dt)
end

function Player:movement(dt)

	local b = self.bDash
	local v = self.velocity
	local key = love.keyboard.isDown

	-- Movement controls
	-- Up
	if key("up") then
		v.y = v.y - v.Increase
		b.Pushed.Up = true
		self.direction = "up"
		self.weapon.direction = "up"
	end

	if key("up") == false and b.Pushed.Up == true then
		b.Timer.Up = b.Timer.Up + dt
		if b.Timer.Up < b.TimeMargin and key("down") then
			b.PartSys:start()
			b.Timer.Up = 0
			b.Pushed.Up = false
			v.y = math.abs(v.y) - 20
		elseif b.Timer.Up > b.TimeMargin then
		 	b.Timer.Up = 0 
		 	b.Pushed.Up = false
		end
	end
	
	-- Down
	if key("down") then
		v.y = v.y + v.Increase
		b.Pushed.Down = true
		self.direction = "down"
		self.weapon.direction = "down"
	end

	if key("down") == false and b.Pushed.Down == true then
		b.Timer.Down = b.Timer.Down + dt
		if b.Timer.Down < b.TimeMargin and key("up") then
			b.PartSys:start()
			b.Timer.Down = 0
			b.Pushed.Down = false
			v.y = -v.y + 20
		elseif b.Timer.Down > b.TimeMargin then
		 	b.Timer.Down = 0 
		 	b.Pushed.Down = false
		end
	end
	
	-- Left
	if key("left") then
		v.x = v.x - v.Increase
		b.Pushed.Left = true
		self.direction = "left"
		self.weapon.direction = "left"
	end

	if key("left") == false and b.Pushed.Left == true then
		b.Timer.Left = b.Timer.Left + dt
		if b.Timer.Left < b.TimeMargin and key("right") then
			b.PartSys:start()
			b.Timer.Left = 0
			b.Pushed.Left = false
			v.x = math.abs(v.x) - 20
		elseif b.Timer.Left > b.TimeMargin then
		 	b.Timer.Left = 0 
		 	b.Pushed.Left = false
		end
	end
	
	-- Right
	if key("right") then
		v.x = v.x + v.Increase
		b.Pushed.Right = true
		self.direction = "right"
		self.weapon.direction = "right"
	end

	if key("right") == false and b.Pushed.Right == true then
		b.Timer.Right = b.Timer.Right + dt
		if b.Timer.Right < b.TimeMargin and key("left") then
			b.PartSys:start()
			b.Timer.Right = 0
			b.Pushed.Right = false
			v.x = -v.x + 20
		elseif b.Timer.Right > b.TimeMargin then
		 	b.Timer.Right = 0 
		 	b.Pushed.Right = false
		end
	end

	-- Decrease velocity if not moving
	if self.allowDecrease == true then
		if key("up") == false and key("down") == false then
			if v.y < 0 then
				v.y = v.y + v.Increase 
			elseif v.y > 0 then
				v.y = v.y - v.Increase 
			end
		end

		if key("left") == false and key("right") == false then
			if v.x < 0 then
				v.x = v.x + v.Increase 
			elseif v.x > 0 then
				v.x = v.x - v.Increase 
			end
		end
	end

	--Forcing
	if self.forced == true then
		self.allowDecrease = false
		v.Max = 200
		self.forceTimer = self.forceTimer + dt
		if self.forceTimer < 0.25 then
			v.x = -self.mX * 10000
			v.y = -self.mY * 10000
		elseif self.forceTimer > 0.25 then
			v.Max = 100
			self.forceTimer = 0
			self.allowDecrease = true
			self.forced = false
		end
	end

	-- Boundary checks
	if v.x < -v.Max then
		v.x = -v.Max
	end

	if v.y < -v.Max then
		v.y = -v.Max
	end

	if v.x > v.Max then
		v.x = v.Max
	end

	if v.y > v.Max then
		v.y = v.Max
	end


	-- Actual movement!
	self.x = self.x + v.x * dt
	self.cBox:move(v.x * dt,0)
	self.y = self.y + v.y * dt
	self.cBox:move(0,v.y * dt)

end

function Player:halt(mtv_x,mtv_y)
	self.cBox:move(-mtv_x,-mtv_y)
	self.x = self.x - mtv_x
	self.y = self.y - mtv_y
end

function Player:force(mtv_x,mtv_y, dt)
	self.mX = mtv_x
	self.mY = mtv_y
	self.forced = true
end