Weapon = class('Weapon', Object)

function Weapon:initialize(x,y)
	Object.initialize(self)
  	
  	self.x = x
  	self.y = y
  	self.direction = "down"
  	self.totalWeapons = 2

  	self.equip = {}

  	self.equip[#self.equip + 1] = Sword:new()
  	self.equip[#self.equip]:initialize()

  	self.fireTimer = 0
  	self.fired = false

  	self.equipped = true
end

function Weapon:draw()
	if self.equipped == true then
		self.equip[#self.equip]:draw()
	end

	if #self.equip > 1 and self.equipped == true then
		for _,v in pairs(self.equip) do
			v:draw()
		end
	end

	love.graphics.setColor(250,100,30)
	love.graphics.point(self.x, self.y)
end

function Weapon:update(dt)

	if self.direction == "up" then
		self.x = self.x + 8
	end

	if self.direction == "down" then
		self.x = self.x + 8
		self.y = self.y + 16
	end

	if self.direction == "left" then
		self.y = self.y + 8
	end

	if self.direction == "right" then
		self.x = self.x + 16
		self.y = self.y + 8
	end

	if self.equipped == true then
		for _,v in pairs(self.equip) do
			v:update(dt)
		end
	end

	for i = #self.equip, 1, -1 do
		if self.equip[i].destruct == true then
			table.remove(self.equip, i)
		end
	end

	self.equip[#self.equip].x = self.x
	self.equip[#self.equip].y = self.y
	self.equip[#self.equip].direction = self.direction

end

function Weapon:swap()
	self.equipped = false

	--Collider:setGhost(self.equip[#self.equip].cBox)
	self.equip[#self.equip].idle = true

	local randomizer = math.random(1,self.totalWeapons)

	if randomizer == 1 then
		self.equip[#self.equip + 1] = Sword:new()
		self.equip[#self.equip]:initialize()
	end

	if randomizer == 2 then
		self.equip[#self.equip + 1] = Bow:new()
		self.equip[#self.equip]:initialize()
	end

	Collider:setSolid(self.equip[#self.equip].cBox)
	self.equipped = true
end

function Weapon:fire(dt)
	if love.keyboard.isDown("z") then

		if self.equip[#self.equip].oneShot == true and self.fired == false then
			self.equip[#self.equip]:fire(dt)
			self.fired = true
		end

		if self.equip[#self.equip].oneShot == false then

			if self.fired == false then
				self.equip[#self.equip]:fire(dt)
				self.fired = true
				self.fireTimer = 0
			end

			self.fireTimer = self.fireTimer + dt

			if self.fireTimer > self.equip[#self.equip].fireRate then
				self.equip[#self.equip]:fire(dt)
				self.fireTimer = 0

			end
		end

	end

	if love.keyboard.isDown("z") == false then
		self.fired = false
	end
end